@@ -417,6 +417,7 @@ def dropdown(text, links, active=None, class_='nav-link dropdown-toggle'):
     -------
     page : :class:`~MarkupPy.markup.page`
         HTML element with the following grammar:
+
         .. code:: html
 
            <a>text</a>
@@ -1209,7 +1210,7 @@ def write_footer(about=None, link=None, issues=None, external=None):
         page.a(markup.oneliner.i('', class_='fas fa-external-link-alt'),
                href=external, title="View this page's external source")
     page.a(markup.oneliner.i('', class_='fas fa-heartbeat'),
-           href='https://attackofthecute.com/random.php',
+           href='https://apod.nasa.gov/apod/astropix.html',
            title='Take a break from science', target='_blank')
     page.div.close()  # col-sm-3 icon-bar
     # print timestamp
